"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var no_case_1 = require("no-case");
var gatsby_plugin_utils_1 = require("gatsby-plugin-utils");
var reporter_1 = __importDefault(require("gatsby-cli/lib/reporter"));
var path_1 = require("path");
var pluginOptionsSchema_1 = require("./pluginOptionsSchema");
var gatsbyPackage = require.resolve("gatsby/package.json");
// Get paths of Gatsby's required rules, which as of writing is located at:
// https://github.com/gatsbyjs/gatsby/tree/fbfe3f63dec23d279a27b54b4057dd611dce74bb/packages/
// gatsby/src/utils/eslint-rules
var gatsbyRequiredRules = (0, path_1.join)((0, path_1.dirname)(gatsbyPackage), "dist", "utils", "eslint-rules");
function validateOptions(options) {
    var _a;
    var schema = (0, pluginOptionsSchema_1.pluginOptionsSchema)({ Joi: gatsby_plugin_utils_1.Joi });
    var warnSchema = schema.pattern(/.*/, gatsby_plugin_utils_1.Joi.any().warning("any.unknown"));
    var validated = warnSchema.validate(options, {
        abortEarly: false,
        externals: false,
    });
    var errors = (_a = validated.error) !== null && _a !== void 0 ? _a : validated.warning;
    if (errors) {
        return reporter_1.default.panic("Configuration errors: ".concat(errors.details
            .map(function (e) { return "".concat(e.message, " @ ").concat(e.path.join(".")); })
            .join(", ")));
    }
    return validated.value;
}
function buildConfig(specifiedOptions) {
    var _a, _b, _c, _d;
    var options = validateOptions(specifiedOptions);
    var gatsbyConfig = {
        plugins: [
            "gatsby-plugin-image",
            {
                resolve: "gatsby-plugin-tsconfig-paths",
                options: {
                    logLevel: "info",
                },
            },
            {
                resolve: "gatsby-plugin-robots-txt",
                options: {
                    resolveEnv: function () {
                        var robotsEnv = options.allowIndex ? "production" : "development";
                        return robotsEnv;
                    },
                    env: {
                        development: {
                            policy: [{ userAgent: "*", disallow: ["/"] }],
                        },
                        production: {
                            policy: [{ userAgent: "*", allow: "/", disallow: ["/dev/"] }],
                        },
                    },
                },
            },
            {
                resolve: "gatsby-plugin-postcss",
                options: {
                    postCssPlugins: [require("tailwindcss"), require("autoprefixer")],
                },
            },
            {
                resolve: "gatsby-plugin-canonical-urls",
                options: {
                    siteUrl: options.siteUrl,
                    stripQueryString: true,
                },
            },
            {
                resolve: "gatsby-plugin-page-creator",
                options: {
                    path: (0, path_1.resolve)("src/pages"),
                    ignore: options.showDevPages
                        ? undefined
                        : {
                            patterns: ["dev/**"],
                            options: { nocase: true },
                        },
                },
            },
            "gatsby-plugin-sitemap",
            {
                resolve: "gatsby-plugin-manifest",
                options: (_a = options.manifestOptions) !== null && _a !== void 0 ? _a : {
                    icon: options.icon,
                },
            },
            {
                resolve: "gatsby-plugin-sharp",
            },
            {
                resolve: "gatsby-transformer-sharp",
                options: {
                    // The option defaults to true
                    checkSupportedExtensions: false,
                },
            },
            {
                resolve: "gatsby-source-filesystem",
                options: {
                    name: "images",
                    path: "./src/images/",
                    fastHash: true,
                },
                __key: "images",
            },
            "@bond-london/gatsby-transformer-extracted-svg",
            "@bond-london/gatsby-transformer-extracted-lottie",
            {
                resolve: "@bond-london/simple-gatsby-source-graphcms",
                options: __assign({ endpoint: options.graphCMSEndpoint, stages: [options.graphCMSStage], token: options.graphCMSToken }, options.sourceOptions),
            },
            {
                resolve: "@bond-london/gatsby-transformer-video",
                options: {
                    useRemoteCache: options.useVideoCache,
                    remoteContainer: (0, no_case_1.noCase)(options.projectName, { delimiter: "" }),
                    remoteConnectionString: options.videoCacheConnectionString,
                    width: options.videoWidth,
                },
            },
        ],
    };
    var cloudPlugin = {
        resolve: "gatsby-plugin-gatsby-cloud",
        options: {
            headers: {
                // eslint-disable-next-line @typescript-eslint/naming-convention
                "/fonts/*": ["Cache-Control: public, max-age=31536000, immutable"],
            },
        },
    };
    if (options.showDevPages) {
        cloudPlugin.options.headers["/*"] = [
            "X-Frame-Options: SAMEORIGIN",
        ];
    }
    (_b = gatsbyConfig.plugins) === null || _b === void 0 ? void 0 : _b.push(cloudPlugin);
    if (options.enableEslint) {
        (_c = gatsbyConfig.plugins) === null || _c === void 0 ? void 0 : _c.push({
            resolve: "gatsby-plugin-eslint",
            options: {
                // Gatsby required rules directory
                rulePaths: [gatsbyRequiredRules],
                // Default settings that may be omitted or customized
                stages: ["develop"],
                extensions: ["js", "jsx", "ts", "tsx"],
                exclude: ["node_modules", "bower_components", ".cache", "public"],
                // Any additional eslint-webpack-plugin options below
                // ...
                overrideConfigFile: ".custom.eslintrc.json",
            },
        });
    }
    if (options.additionalPlugins) {
        (_d = gatsbyConfig.plugins) === null || _d === void 0 ? void 0 : _d.push.apply(_d, __spreadArray([], __read(options.additionalPlugins), false));
    }
    return gatsbyConfig;
}
exports.default = buildConfig;
